import type { Workflow, INode, IWorkflowExecuteAdditionalData, WorkflowExecuteMode, IRunExecutionData, INodeExecutionData, ITaskDataConnections, IExecuteData, ICredentialDataDecryptedObject, CallbackManager, IExecuteWorkflowInfo, RelatedExecution, ExecuteWorkflowData, ITaskMetadata, ContextType, IContextObject, INodeInputConfiguration, INodeOutputConfiguration, IWorkflowDataProxyData, ISourceData, AiEvent } from 'n8n-workflow';
import { BinaryDataService } from '../BinaryData/BinaryData.service';
import { NodeExecutionContext } from './node-execution-context';
export declare class BaseExecuteContext extends NodeExecutionContext {
    protected readonly runExecutionData: IRunExecutionData;
    protected readonly connectionInputData: INodeExecutionData[];
    protected readonly inputData: ITaskDataConnections;
    protected readonly executeData: IExecuteData;
    protected readonly abortSignal?: AbortSignal | undefined;
    protected readonly binaryDataService: BinaryDataService;
    constructor(workflow: Workflow, node: INode, additionalData: IWorkflowExecuteAdditionalData, mode: WorkflowExecuteMode, runExecutionData: IRunExecutionData, runIndex: number, connectionInputData: INodeExecutionData[], inputData: ITaskDataConnections, executeData: IExecuteData, abortSignal?: AbortSignal | undefined);
    getExecutionCancelSignal(): AbortSignal | undefined;
    onExecutionCancellation(handler: () => unknown): void;
    getExecuteData(): IExecuteData;
    setMetadata(metadata: ITaskMetadata): void;
    getContext(type: ContextType): IContextObject;
    continueOnFail(): boolean;
    getCredentials<T extends object = ICredentialDataDecryptedObject>(type: string, itemIndex: number): Promise<T>;
    executeWorkflow(workflowInfo: IExecuteWorkflowInfo, inputData?: INodeExecutionData[], parentCallbackManager?: CallbackManager, options?: {
        doNotWaitToFinish?: boolean;
        parentExecution?: RelatedExecution;
    }): Promise<ExecuteWorkflowData>;
    getNodeInputs(): INodeInputConfiguration[];
    getNodeOutputs(): INodeOutputConfiguration[];
    getInputSourceData(inputIndex?: number, inputName?: string): ISourceData;
    getWorkflowDataProxy(itemIndex: number): IWorkflowDataProxyData;
    sendMessageToUI(...args: any[]): void;
    logAiEvent(eventName: AiEvent, msg: string): void;
}
