"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ExecuteContext = void 0;
const n8n_workflow_1 = require("n8n-workflow");
const Agent_1 = require("../Agent");
const NodeExecuteFunctions_1 = require("../NodeExecuteFunctions");
const base_execute_context_1 = require("./base-execute-context");
class ExecuteContext extends base_execute_context_1.BaseExecuteContext {
    constructor(workflow, node, additionalData, mode, runExecutionData, runIndex, connectionInputData, inputData, executeData, closeFunctions, abortSignal) {
        super(workflow, node, additionalData, mode, runExecutionData, runIndex, connectionInputData, inputData, executeData, abortSignal);
        this.closeFunctions = closeFunctions;
        this.helpers = {
            createDeferredPromise: n8n_workflow_1.createDeferredPromise,
            returnJsonArray: NodeExecuteFunctions_1.returnJsonArray,
            copyInputItems: NodeExecuteFunctions_1.copyInputItems,
            normalizeItems: NodeExecuteFunctions_1.normalizeItems,
            constructExecutionMetaData: NodeExecuteFunctions_1.constructExecutionMetaData,
            ...(0, NodeExecuteFunctions_1.getRequestHelperFunctions)(workflow, node, additionalData, runExecutionData, connectionInputData),
            ...(0, NodeExecuteFunctions_1.getBinaryHelperFunctions)(additionalData, workflow.id),
            ...(0, NodeExecuteFunctions_1.getSSHTunnelFunctions)(),
            ...(0, NodeExecuteFunctions_1.getFileSystemHelperFunctions)(node),
            ...(0, NodeExecuteFunctions_1.getCheckProcessedHelperFunctions)(workflow, node),
            assertBinaryData: (itemIndex, propertyName) => (0, NodeExecuteFunctions_1.assertBinaryData)(inputData, node, itemIndex, propertyName, 0),
            getBinaryDataBuffer: async (itemIndex, propertyName) => await (0, NodeExecuteFunctions_1.getBinaryDataBuffer)(inputData, itemIndex, propertyName, 0),
        };
        this.nodeHelpers = {
            copyBinaryFile: async (filePath, fileName, mimeType) => await (0, NodeExecuteFunctions_1.copyBinaryFile)(this.workflow.id, this.additionalData.executionId, filePath, fileName, mimeType),
        };
        this.getNodeParameter = ((parameterName, itemIndex, fallbackValue, options) => this._getNodeParameter(parameterName, itemIndex, fallbackValue, options));
        this.startJob = (0, Agent_1.createAgentStartJob)(this.additionalData, this.inputData, this.node, this.workflow, this.runExecutionData, this.runIndex, this.node.name, this.connectionInputData, {}, this.mode, this.executeData);
    }
    async getInputConnectionData(inputName, itemIndex) {
        return await NodeExecuteFunctions_1.getInputConnectionData.call(this, this.workflow, this.runExecutionData, this.runIndex, this.connectionInputData, this.inputData, this.additionalData, this.executeData, this.mode, this.closeFunctions, inputName, itemIndex, this.abortSignal);
    }
    getInputData(inputIndex = 0, inputName = 'main') {
        if (!this.inputData.hasOwnProperty(inputName)) {
            return [];
        }
        const inputData = this.inputData[inputName];
        if (inputData.length < inputIndex) {
            throw new n8n_workflow_1.ApplicationError('Could not get input with given index', {
                extra: { inputIndex, inputName },
            });
        }
        if (inputData[inputIndex] === null) {
            throw new n8n_workflow_1.ApplicationError('Value of input was not set', {
                extra: { inputIndex, inputName },
            });
        }
        return inputData[inputIndex];
    }
    async putExecutionToWait(waitTill) {
        this.runExecutionData.waitTill = waitTill;
        if (this.additionalData.setExecutionStatus) {
            this.additionalData.setExecutionStatus('waiting');
        }
    }
    logNodeOutput(...args) {
        if (this.mode === 'manual') {
            this.sendMessageToUI(...args);
            return;
        }
        if (process.env.CODE_ENABLE_STDOUT === 'true') {
            console.log(`[Workflow "${this.getWorkflow().id}"][Node "${this.node.name}"]`, ...args);
        }
    }
    async sendResponse(response) {
        await this.additionalData.hooks?.executeHookFunctions('sendResponse', [response]);
    }
    addInputData(connectionType, data) {
        const nodeName = this.node.name;
        let currentNodeRunIndex = 0;
        if (this.runExecutionData.resultData.runData.hasOwnProperty(nodeName)) {
            currentNodeRunIndex = this.runExecutionData.resultData.runData[nodeName].length;
        }
        void (0, NodeExecuteFunctions_1.addExecutionDataFunctions)('input', nodeName, data, this.runExecutionData, connectionType, this.additionalData, nodeName, this.runIndex, currentNodeRunIndex).catch((error) => {
            this.logger.warn(`There was a problem logging input data of node "${nodeName}": ${error.message}`);
        });
        return { index: currentNodeRunIndex };
    }
    addOutputData(connectionType, currentNodeRunIndex, data, metadata) {
        const nodeName = this.node.name;
        (0, NodeExecuteFunctions_1.addExecutionDataFunctions)('output', nodeName, data, this.runExecutionData, connectionType, this.additionalData, nodeName, this.runIndex, currentNodeRunIndex, metadata).catch((error) => {
            this.logger.warn(`There was a problem logging output data of node "${nodeName}": ${error.message}`);
        });
    }
    getParentCallbackManager() {
        return this.additionalData.parentCallbackManager;
    }
}
exports.ExecuteContext = ExecuteContext;
//# sourceMappingURL=execute-context.js.map