import type { FunctionsBase, ICredentialDataDecryptedObject, IExecuteData, IGetNodeParameterOptions, INode, INodeExecutionData, IRunExecutionData, IWorkflowExecuteAdditionalData, NodeParameterValueType, NodeTypeAndVersion, Workflow, WorkflowExecuteMode } from 'n8n-workflow';
import { LoggerProxy } from 'n8n-workflow';
import { InstanceSettings } from '../InstanceSettings';
export declare abstract class NodeExecutionContext implements Omit<FunctionsBase, 'getCredentials'> {
    protected readonly workflow: Workflow;
    protected readonly node: INode;
    protected readonly additionalData: IWorkflowExecuteAdditionalData;
    protected readonly mode: WorkflowExecuteMode;
    protected readonly runExecutionData: IRunExecutionData | null;
    protected readonly runIndex: number;
    protected readonly connectionInputData: INodeExecutionData[];
    protected readonly executeData?: IExecuteData | undefined;
    protected readonly instanceSettings: InstanceSettings;
    constructor(workflow: Workflow, node: INode, additionalData: IWorkflowExecuteAdditionalData, mode: WorkflowExecuteMode, runExecutionData?: IRunExecutionData | null, runIndex?: number, connectionInputData?: INodeExecutionData[], executeData?: IExecuteData | undefined);
    get logger(): typeof LoggerProxy;
    getExecutionId(): string;
    getNode(): INode;
    getWorkflow(): {
        id: string;
        name: string | undefined;
        active: boolean;
    };
    getMode(): WorkflowExecuteMode;
    getWorkflowStaticData(type: string): import("n8n-workflow").IDataObject;
    getChildNodes(nodeName: string): NodeTypeAndVersion[];
    getParentNodes(nodeName: string): NodeTypeAndVersion[];
    getKnownNodeTypes(): import("n8n-workflow").IDataObject;
    getRestApiUrl(): string;
    getInstanceBaseUrl(): string;
    getInstanceId(): string;
    getTimezone(): string;
    getCredentialsProperties(type: string): import("n8n-workflow").INodeProperties[];
    protected _getCredentials<T extends object = ICredentialDataDecryptedObject>(type: string, executeData?: IExecuteData, connectionInputData?: INodeExecutionData[], itemIndex?: number): Promise<T>;
    protected get additionalKeys(): import("n8n-workflow").IDataObject;
    getNodeParameter(parameterName: string, fallbackValue?: any, options?: IGetNodeParameterOptions): NodeParameterValueType | object;
    protected _getNodeParameter(parameterName: string, itemIndex: number, fallbackValue?: any, options?: IGetNodeParameterOptions): NodeParameterValueType | object;
    evaluateExpression(expression: string, itemIndex?: number): import("n8n-workflow").NodeParameterValue | import("n8n-workflow").INodeParameters | import("n8n-workflow").INodeParameters[] | import("n8n-workflow").NodeParameterValue[];
    prepareOutputData(outputData: INodeExecutionData[]): Promise<INodeExecutionData[][]>;
}
