"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SupplyDataContext = void 0;
const n8n_workflow_1 = require("n8n-workflow");
const NodeExecuteFunctions_1 = require("../NodeExecuteFunctions");
const base_execute_context_1 = require("./base-execute-context");
class SupplyDataContext extends base_execute_context_1.BaseExecuteContext {
    constructor(workflow, node, additionalData, mode, runExecutionData, runIndex, connectionInputData, inputData, executeData, closeFunctions, abortSignal) {
        super(workflow, node, additionalData, mode, runExecutionData, runIndex, connectionInputData, inputData, executeData, abortSignal);
        this.closeFunctions = closeFunctions;
        this.helpers = {
            createDeferredPromise: n8n_workflow_1.createDeferredPromise,
            copyInputItems: NodeExecuteFunctions_1.copyInputItems,
            ...(0, NodeExecuteFunctions_1.getRequestHelperFunctions)(workflow, node, additionalData, runExecutionData, connectionInputData),
            ...(0, NodeExecuteFunctions_1.getSSHTunnelFunctions)(),
            ...(0, NodeExecuteFunctions_1.getFileSystemHelperFunctions)(node),
            ...(0, NodeExecuteFunctions_1.getBinaryHelperFunctions)(additionalData, workflow.id),
            ...(0, NodeExecuteFunctions_1.getCheckProcessedHelperFunctions)(workflow, node),
            assertBinaryData: (itemIndex, propertyName) => (0, NodeExecuteFunctions_1.assertBinaryData)(inputData, node, itemIndex, propertyName, 0),
            getBinaryDataBuffer: async (itemIndex, propertyName) => await (0, NodeExecuteFunctions_1.getBinaryDataBuffer)(inputData, itemIndex, propertyName, 0),
            returnJsonArray: NodeExecuteFunctions_1.returnJsonArray,
            normalizeItems: NodeExecuteFunctions_1.normalizeItems,
            constructExecutionMetaData: NodeExecuteFunctions_1.constructExecutionMetaData,
        };
        this.getNodeParameter = ((parameterName, itemIndex, fallbackValue, options) => this._getNodeParameter(parameterName, itemIndex, fallbackValue, options));
    }
    async getInputConnectionData(inputName, itemIndex) {
        return await NodeExecuteFunctions_1.getInputConnectionData.call(this, this.workflow, this.runExecutionData, this.runIndex, this.connectionInputData, this.inputData, this.additionalData, this.executeData, this.mode, this.closeFunctions, inputName, itemIndex, this.abortSignal);
    }
    getInputData(inputIndex = 0, inputName = 'main') {
        if (!this.inputData.hasOwnProperty(inputName)) {
            return [];
        }
        if (this.inputData[inputName].length < inputIndex) {
            throw new n8n_workflow_1.ApplicationError('Could not get input with given index', {
                extra: { inputIndex, inputName },
            });
        }
        if (this.inputData[inputName][inputIndex] === null) {
            throw new n8n_workflow_1.ApplicationError('Value of input was not set', {
                extra: { inputIndex, inputName },
            });
        }
        return this.inputData[inputName][inputIndex];
    }
    addInputData(connectionType, data) {
        const nodeName = this.node.name;
        let currentNodeRunIndex = 0;
        if (this.runExecutionData.resultData.runData.hasOwnProperty(nodeName)) {
            currentNodeRunIndex = this.runExecutionData.resultData.runData[nodeName].length;
        }
        (0, NodeExecuteFunctions_1.addExecutionDataFunctions)('input', nodeName, data, this.runExecutionData, connectionType, this.additionalData, nodeName, this.runIndex, currentNodeRunIndex).catch((error) => {
            this.logger.warn(`There was a problem logging input data of node "${nodeName}": ${error.message}`);
        });
        return { index: currentNodeRunIndex };
    }
    addOutputData(connectionType, currentNodeRunIndex, data, metadata) {
        const nodeName = this.node.name;
        (0, NodeExecuteFunctions_1.addExecutionDataFunctions)('output', nodeName, data, this.runExecutionData, connectionType, this.additionalData, nodeName, this.runIndex, currentNodeRunIndex, metadata).catch((error) => {
            this.logger.warn(`There was a problem logging output data of node "${nodeName}": ${error.message}`);
        });
    }
}
exports.SupplyDataContext = SupplyDataContext;
//# sourceMappingURL=supply-data-context.js.map